class data_operations():

    '''
    Pacote construído para a manipulação de um banco de dados e 
    retorno de resultados, baseado nas condições definidas pelo usuário.
    '''

    def __init__(self):
        pass


    def desvio_padrao():
        pass


    def diferenca():
        pass


    def media():
        pass


    def mediana():
        pass


    def moda():
        pass


    def porcentagem():
        pass


    def selecao():
        pass


    def somatorio():
        pass


    def variancia():
        pass


    pass
